package de.intevation.flys.artifacts.services;

import java.util.List;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.intevation.artifacts.CallMeta;
import de.intevation.artifacts.GlobalContext;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.flys.themes.Theme;
import de.intevation.flys.themes.ThemeGroup;

import de.intevation.flys.themes.ThemeFactory;
import de.intevation.flys.artifacts.context.FLYSContext;

/**
 * This service provides a list of themes filtered by the theme name.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class ThemeListingService extends FLYSService {

    /** The logger used in this service.*/
    private static Logger logger = Logger.getLogger(ThemeListingService.class);

    private static final String XPATH_THEME_NAME = "/theme/@name";

    protected Document doProcess(
        Document      data,
        GlobalContext context,
        CallMeta      callMeta
    ) {
        logger.debug("ThemeListingService.process");
        String name = XMLUtils.xpathString(data, XPATH_THEME_NAME, null);

        if (name == null) {
            logger.warn("No theme name provided.");
        }
        Document result = XMLUtils.newDocument();

        XMLUtils.ElementCreator ec = new XMLUtils.ElementCreator(
            result,
            null,
            null);

        List<ThemeGroup> tgs =
            ThemeFactory.getThemeGroups((FLYSContext) context);

        Element te = ec.create("themes");

        for (ThemeGroup tg: tgs) {
            Element elem = ec.create("themegroup");
            if (tg.getName().equals("virtual")) {
                continue;
            }
            ec.addAttr(elem, "name", tg.getName());
            Theme theme = tg.getThemeByName(name);
            Document d = theme.toXML();
            Node imported = result.importNode(d.getDocumentElement(), true);
            elem.appendChild(imported);
            te.appendChild(elem);
        }

        result.appendChild(te);
        return result;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
